==> qtjambi-location-debuginfo-macos-5.15.17.jar: sources/QtJambiLocation/QPlaceManagerEngine_shell.h <==
#ifndef QPLACEMANAGERENGINE_SHELL_H
#define QPLACEMANAGERENGINE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtLocation/qplacemanagerengine.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtLocation/qplace.h>
#include <QtLocation/qplacecategory.h>
#include <QtLocation/qplacecontentreply.h>
#include <QtLocation/qplacecontentrequest.h>
#include <QtLocation/qplacedetailsreply.h>
#include <QtLocation/qplaceicon.h>
#include <QtLocation/qplaceidreply.h>
#include <QtLocation/qplacemanager.h>
#include <QtLocation/qplacematchreply.h>
#include <QtLocation/qplacematchrequest.h>
#include <QtLocation/qplacereply.h>
#include <QtLocation/qplacesearchreply.h>
#include <QtLocation/qplacesearchrequest.h>
#include <QtLocation/qplacesearchsuggestionreply.h>
#include <QtJambi/RegistryAPI>


class QPlaceManagerEngine_shell : public QPlaceManagerEngine, public QtJambiShellInterface
{
public:
    QPlaceManagerEngine_shell(const QMap<QString, QVariant>& parameters0, QObject* parent1 = nullptr);
    ~QPlaceManagerEngine_shell() override;

    QPlaceCategory category(const QString& categoryId0) const override;
    QList<QPlaceCategory> childCategories(const QString& parentId0) const override;
    QStringList childCategoryIds(const QString& categoryId0) const override;
    void childEvent(QChildEvent* event0) override;
    QPlace compatiblePlace(const QPlace& original0) const override;
    void connectNotify(const QMetaMethod& signal0) override;
    QUrl constructIconUrl(const QPlaceIcon& icon0, const QSize& size1) const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QPlaceContentReply* getPlaceContent(const QPlaceContentRequest& request0) override;
    QPlaceDetailsReply* getPlaceDetails(const QString& placeId0) override;
    QPlaceReply* initializeCategories() override;
    QList<QLocale> locales() const override;
    QPlaceMatchReply* matchingPlaces(const QPlaceMatchRequest& request0) override;
    QString parentCategoryId(const QString& categoryId0) const override;
    QPlaceIdReply* removeCategory(const QString& categoryId0) override;
    QPlaceIdReply* removePlace(const QString& placeId0) override;
    QPlaceIdReply* saveCategory(const QPlaceCategory& category0, const QString& parentId1) override;
    QPlaceIdReply* savePlace(const QPlace& place0) override;
    QPlaceSearchReply* search(const QPlaceSearchRequest& request0) override;
    QPlaceSearchSuggestionReply* searchSuggestions(const QPlaceSearchRequest& request0) override;
    void setLocales(const QList<QLocale>& locales0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPlaceManagerEngine_access : public QPlaceManagerEngine
{
    jobject __qt_manager(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_category_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring categoryId0) const;
    jobject __qt_childCategories_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring parentId0) const;
    jobject __qt_childCategoryIds_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring categoryId0) const;
    jobject __qt_compatiblePlace_cref_QPlace_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID original0) const;
    jobject __qt_constructIconUrl_cref_QPlaceIcon_cref_QSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID icon0, QtJambiNativeID size1) const;
    jobject __qt_getPlaceContent_cref_QPlaceContentRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    jobject __qt_getPlaceDetails_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring placeId0);
    jobject __qt_initializeCategories(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_locales(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_matchingPlaces_cref_QPlaceMatchRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    jstring __qt_parentCategoryId_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring categoryId0) const;
    jobject __qt_removeCategory_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring categoryId0);
    jobject __qt_removePlace_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring placeId0);
    jobject __qt_saveCategory_cref_QPlaceCategory_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID category0, jstring parentId1);
    jobject __qt_savePlace_cref_QPlace(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID place0);
    jobject __qt_search_cref_QPlaceSearchRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    jobject __qt_searchSuggestions_cref_QPlaceSearchRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    void __qt_setLocales_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject locales0);
};

#endif // QPLACEMANAGERENGINE_SHELL_H

==> qtjambi-location-debuginfo-macos-5.15.20.jar: sources/QtJambiLocation/QPlaceManagerEngine_shell.h <==
#ifndef QPLACEMANAGERENGINE_SHELL_H
#define QPLACEMANAGERENGINE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtLocation/qplacemanagerengine.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtLocation/qplace.h>
#include <QtLocation/qplacecategory.h>
#include <QtLocation/qplacecontentreply.h>
#include <QtLocation/qplacecontentrequest.h>
#include <QtLocation/qplacedetailsreply.h>
#include <QtLocation/qplaceicon.h>
#include <QtLocation/qplaceidreply.h>
#include <QtLocation/qplacemanager.h>
#include <QtLocation/qplacematchreply.h>
#include <QtLocation/qplacematchrequest.h>
#include <QtLocation/qplacereply.h>
#include <QtLocation/qplacesearchreply.h>
#include <QtLocation/qplacesearchrequest.h>
#include <QtLocation/qplacesearchsuggestionreply.h>
#include <QtJambi/RegistryAPI>


class QPlaceManagerEngine_shell : public QPlaceManagerEngine, public QtJambiShellInterface
{
public:
    QPlaceManagerEngine_shell(const QMap<QString, QVariant>& parameters0, QObject* parent1 = nullptr);
    ~QPlaceManagerEngine_shell() override;

    QPlaceCategory category(const QString& categoryId0) const override;
    QList<QPlaceCategory> childCategories(const QString& parentId0) const override;
    QStringList childCategoryIds(const QString& categoryId0) const override;
    void childEvent(QChildEvent* event0) override;
    QPlace compatiblePlace(const QPlace& original0) const override;
    void connectNotify(const QMetaMethod& signal0) override;
    QUrl constructIconUrl(const QPlaceIcon& icon0, const QSize& size1) const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QPlaceContentReply* getPlaceContent(const QPlaceContentRequest& request0) override;
    QPlaceDetailsReply* getPlaceDetails(const QString& placeId0) override;
    QPlaceReply* initializeCategories() override;
    QList<QLocale> locales() const override;
    QPlaceMatchReply* matchingPlaces(const QPlaceMatchRequest& request0) override;
    QString parentCategoryId(const QString& categoryId0) const override;
    QPlaceIdReply* removeCategory(const QString& categoryId0) override;
    QPlaceIdReply* removePlace(const QString& placeId0) override;
    QPlaceIdReply* saveCategory(const QPlaceCategory& category0, const QString& parentId1) override;
    QPlaceIdReply* savePlace(const QPlace& place0) override;
    QPlaceSearchReply* search(const QPlaceSearchRequest& request0) override;
    QPlaceSearchSuggestionReply* searchSuggestions(const QPlaceSearchRequest& request0) override;
    void setLocales(const QList<QLocale>& locales0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPlaceManagerEngine_access : public QPlaceManagerEngine
{
    jobject __qt_manager_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_category_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring categoryId0) const;
    jobject __qt_childCategories_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring parentId0) const;
    jobject __qt_childCategoryIds_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring categoryId0) const;
    jobject __qt_compatiblePlace_cref_QPlace_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID original0) const;
    jobject __qt_constructIconUrl_cref_QPlaceIcon_cref_QSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID icon0, QtJambiNativeID size1) const;
    jobject __qt_getPlaceContent_cref_QPlaceContentRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    jobject __qt_getPlaceDetails_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring placeId0);
    jobject __qt_initializeCategories(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_locales_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_matchingPlaces_cref_QPlaceMatchRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    jstring __qt_parentCategoryId_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring categoryId0) const;
    jobject __qt_removeCategory_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring categoryId0);
    jobject __qt_removePlace_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring placeId0);
    jobject __qt_saveCategory_cref_QPlaceCategory_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID category0, jstring parentId1);
    jobject __qt_savePlace_cref_QPlace(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID place0);
    jobject __qt_search_cref_QPlaceSearchRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    jobject __qt_searchSuggestions_cref_QPlaceSearchRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    void __qt_setLocales_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject locales0);
};

#endif // QPLACEMANAGERENGINE_SHELL_H
